@@ -1,6 +1,6 @@
 /****************** Start of $RCSfile: buutil.c,v $  ****************
 *
-* $Source: /home/alb/afbackup/afbackup-3.5.2.1/RCS/buutil.c,v $
+* $Source: /home/alb/afbackup/afbackup-3.5.2.2/RCS/buutil.c,v $
 * $Id: buutil.c,v 1.5 2005/01/15 08:49:21 alb Exp alb $
 * $Date: 2005/01/15 08:49:21 $
 * $Author: alb $
@@ -15,7 +15,7 @@
 #include <conf.h>
 #include <version.h>
 
-  static char * fileversion = "$RCSfile: buutil.c,v $ $Source: /home/alb/afbackup/afbackup-3.5.2.1/RCS/buutil.c,v $ $Id: buutil.c,v 1.5 2005/01/15 08:49:21 alb Exp alb $ " PACKAGE " " VERSION_STRING;
+  static char * fileversion = "$RCSfile: buutil.c,v $ $Source: /home/alb/afbackup/afbackup-3.5.2.2/RCS/buutil.c,v $ $Id: buutil.c,v 1.5 2005/01/15 08:49:21 alb Exp alb $ " PACKAGE " " VERSION_STRING;
 
 #include <stdio.h>
 #include <string.h>
@@ -713,7 +713,8 @@ devices_from_confstr(
 		  nchr_1 = num_changers;
 		  num_changers++;
 
-		  changers[nchr_1].changername = NEWP(UChar, (n = chgptr - devptr) + 1);
+		  n = chgptr - devptr;
+		  changers[nchr_1].changername = NEWP(UChar, n + 1);
 		  if(!changers[nchr_1].changername)
 		    GETOUTR(BUDEVCONF_NOMEM);
 
@@ -920,6 +921,31 @@ free_devices_and_changers(
   }
 }
 
+ChangerDevice *
+changer_by_device(
+  UChar			*devicename,
+  StreamerDevice	*deviceslist,
+  Int32			num_streamers)
+{
+  Int32		i;
+  UChar		*curdev;
+
+  if(!devicename || !deviceslist){
+    errno = EINVAL;
+    return(NULL);
+  }
+
+  for(i = 0; i < num_streamers; i++){
+    curdev = deviceslist[i].devicename;
+    if(curdev){
+	if(!strcmp(curdev, devicename))
+	  return(deviceslist[i].changer);
+    }
+  }
+
+  return(NULL);
+}
+
 UChar *
 repl_dev_pats(UChar * str, UChar * streamer, UChar * changer)
 {
