@@ -20,6 +20,8 @@
 #ifndef __X_REGEXP_LIBRARY_H__
 #define __X_REGEXP_LIBRARY_H__
 
+#include <lconf.h>
+
 #include <x_types.h>
 
 #define	REGEX_Real32	\
@@ -27,11 +29,11 @@
 #define REGEX_INT	\
 "[ \n\t]*[-+]?[1-9][0-9]*"
 
-#ifdef	linux
+#ifdef	INC_REGEX_H
 #include <regex.h>
-#else
+#endif
 
-#include "x_types.h"
+#ifdef	DECL_RE_UTILS
 
 /* POSIX says that <sys/types.h> must be included (by the caller) before
    <regex.h>.  */
@@ -221,6 +223,8 @@ extern reg_syntax_t re_syntax_options;
 #define RE_DUP_MAX ((1 << 15) - 1) 
 
 
+#ifdef	DECL_POSIX_REGEX
+
 /* POSIX `cflags' bits (i.e., information for `regcomp').  */
 
 /* If this bit is set, then use extended regular expression syntax.
@@ -253,35 +257,36 @@ extern reg_syntax_t re_syntax_options;
 /* Like REG_NOTBOL, except for the end-of-line.  */
 #define REG_NOTEOL (1 << 1)
 
-
 /* If any error codes are removed, changed, or added, update the
    `re_error_msg' table in regex.c.  */
-typedef enum
-{
-  REG_NOERROR = 0,	/* Success.  */
-  REG_NOMATCH,		/* Didn't find a match (for regexec).  */
 
   /* POSIX regcomp return error codes.  (In the order listed in the
      standard.)  */
-  REG_BADPAT,		/* Invalid pattern.  */
-  REG_ECOLLATE,		/* Not implemented.  */
-  REG_ECTYPE,		/* Invalid character class name.  */
-  REG_EESCAPE,		/* Trailing backslash.  */
-  REG_ESUBREG,		/* Invalid back reference.  */
-  REG_EBRACK,		/* Unmatched left bracket.  */
-  REG_EPAREN,		/* Parenthesis imbalance.  */ 
-  REG_EBRACE,		/* Unmatched \{.  */
-  REG_BADBR,		/* Invalid contents of \{\}.  */
-  REG_ERANGE,		/* Invalid range end.  */
-  REG_ESPACE,		/* Ran out of memory.  */
-  REG_BADRPT,		/* No preceding re for repetition op.  */
+#define REG_BADPAT      2       /* Invalid Regular Expression */
+#define REG_BADBR       3       /* Invalid \{ \} range exp */
+#define	REG_NOMATCH	20	/* Didn't find a match (for regexec).  */
+#define REG_ECOLLATE    21      /* Invalid collating element */
+#define REG_EESCAPE     22      /* Last character is \ */
+#define REG_ERANGE      23      /* Invalid range exp endpoint */
+#define REG_ECTYPE      24      /* Invalid character class */
+#define REG_ESUBREG     25      /* Invalid number in \digit */
+#define REG_BADRPT      26      /* ?*+ not preceded by valid RE */
+#define REG_EPAREN      42      /* \( \) or () imbalance */
+#define REG_EBRACE      45      /* \{ \} or { } imbalance */
+#define REG_EBRACK      49      /* [] imbalance */
+#define REG_ESPACE      50      /* Out of memory */
+
+#endif	/* defined(DECL_POSIX_REGEX) */
 
   /* Error codes we've added.  */
-  REG_EEND,		/* Premature end.  */
-  REG_ESIZE,		/* Compiled pattern bigger than 2^16 bytes.  */
-  REG_ERPAREN		/* Unmatched ) or \); not returned from regcomp.  */
-} reg_errcode_t;
+#define	REG_NOERROR	0	/* Success.  */
+
+#define	REG_EEND	1001	/* Premature end.  */
+#define	REG_ESIZE	1002	/* Compiled pattern bigger than 2^16 bytes.  */
+#define	REG_ERPAREN	1003	/* Unmatched ) or \); not returned from regcomp.  */
 
+typedef	Uns32	reg_errcode_t;
+
 /* This data structure represents a compiled pattern.  Before calling
    the pattern compiler, the fields `buffer', `allocated', `fastmap',
    `translate', and `no_sub' can be set.  After the pattern has been
@@ -356,17 +361,20 @@ struct re_pattern_buffer
 /* [[[end pattern_buffer]]] */
 };
 
+#ifdef	DECL_POSIX_REGEX
+
 typedef struct re_pattern_buffer regex_t;
 
+/* Type for byte offsets within the string.  POSIX mandates this.  */
+typedef Int32 regoff_t;
+
+#endif
+
 
 /* search.c (search_buffer) in Emacs needs this one opcode value.  It is
    defined both in `regex.c' and here.  */
 #define RE_EXACTN_VALUE 1
 
-/* Type for byte offsets within the string.  POSIX mandates this.  */
-typedef Int32 regoff_t;
-
-
 /* This is the structure we store register match data in.  See
    regex.texinfo for a full description of what registers match.  */
 struct re_registers
@@ -385,6 +393,8 @@ struct re_registers
 #endif
 
 
+#ifdef	DECL_POSIX_REGEX
+
 /* POSIX specification for registers.  Aside from the different names than
    `re_registers', POSIX uses an array of structures, instead of a
    structure of arrays.  */
@@ -393,7 +403,9 @@ typedef struct
   regoff_t rm_so;  /* Byte offset from string's start to substring's start.  */
   regoff_t rm_eo;  /* Byte offset from string's start to substring's end.  */
 } regmatch_t;
-
+
+#endif
+
 /* Declarations for routines.  */
 
 /* To avoid duplicating every routine declaration -- once with a
@@ -478,14 +490,15 @@ extern void re_set_registers
   _RE_ARGS ((struct re_pattern_buffer *buffer, struct re_registers *regs,
              Uns32 num_regs, regoff_t *starts, regoff_t *ends));
 
-/* 4.2 bsd compatibility.  */
-#if defined(sgi) || defined(__FreeBSD__)
+#ifndef	DEF_RE_COMP
 #include	<unistd.h>
 #else
 extern UChar *re_comp _RE_ARGS ((UChar *));
 extern Int32 re_exec _RE_ARGS ((UChar *));
 #endif
 
+#ifdef	DECL_POSIX_REGEX
+
 /* POSIX compatibility.  */
 extern Int32 regcomp _RE_ARGS ((regex_t *preg, UChar *pattern, Int32 cflags));
 extern Int32 regexec
@@ -496,15 +509,17 @@ extern size_t regerror
              size_t errbuf_size));
 extern void regfree _RE_ARGS ((regex_t *preg));
 
-#endif	/* defined(linux) */
+#endif	/* defined(DECL_POSIX_REGEX) */
+
+#endif	/* defined(DECL_RE_UTILS) */
+
+typedef	struct re_pattern_buffer	RE_cmp_buffer;
 
 extern Int32	re_find_match (struct re_pattern_buffer *, UChar *,
 			Int32 *, Int32 *);
 extern Int32	re_find_match_once(UChar *, UChar *, Int32 *, Int32 *);
-
-typedef	struct re_pattern_buffer	RE_cmp_buffer;
-
-#define	re_free	regfree
+extern Int32	args_to_regexarr(RE_cmp_buffer **, UChar *);
+#define	re_free(re)	regfree(re)
 
 #endif /* ! __X_REGEXP_LIBRARY_H__ */
 
